/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/

#include        "init.h"

int
main(int argc,char ** argv)
{
	char * msg;

	printf("%s is executed. \n", argv[0]);

	check_endian();
	init_task(INI_DONTWAITCHI);
	init_tick();
	init_d_alloc();
	init_longchar();
	init_stream();
	init_utils();
	init_netutils();
	init_resolve();

	if ( argc > 1 && argv[1][0] == '+' ) {
		int i;
		/*
		msg = argv[1];
		argv[1] = argv[0];
		argv ++;
		argc --;
		proc_recv_stream(msg);
		*/
		proc_recv_stream(&(argv[1][1]));
		argv +=2;
		argc -=2;
		for(i=0;i<argc;++i){
			printf("arg%d=%s\n", i, argv[i]);
		}
	}
	
	return _main(argc,argv);
}
